@@ -37,15 +37,8 @@
 #include "eel-canvas-rect-ellipse.h"
 #include <string.h>
 
-#ifdef HAVE_RENDER
-#include <gdk/gdkx.h>
-#include <X11/extensions/Xrender.h>
-#endif
-
 /* Base class for rectangle and ellipse item types */
 
-#define noVERBOSE
-
 enum
 {
     PROP_0,
@@ -208,45 +201,6 @@ eel_canvas_re_init (EelCanvasRE *re)
     re->width = 0.0;
 }
 
-static void get_bounds (EelCanvasRE *re, double *px1, double *py1, double *px2, double *py2)
-{
-    EelCanvasItem *item;
-    double x1, y1, x2, y2;
-    int cx1, cy1, cx2, cy2;
-    double hwidth;
-
-#ifdef VERBOSE
-    g_print ("re get_bounds\n");
-#endif
-    item = EEL_CANVAS_ITEM (re);
-
-    if (re->width_pixels)
-        hwidth = (re->width / item->canvas->pixels_per_unit) / 2.0;
-    else
-        hwidth = re->width / 2.0;
-
-    x1 = re->x1;
-    y1 = re->y1;
-    x2 = re->x2;
-    y2 = re->y2;
-
-    eel_canvas_item_i2w (item, &x1, &y1);
-    eel_canvas_item_i2w (item, &x2, &y2);
-    eel_canvas_w2c (item->canvas, x1 - hwidth, y1 - hwidth, &cx1, &cy1);
-    eel_canvas_w2c (item->canvas, x2 + hwidth, y2 + hwidth, &cx2, &cy2);
-    *px1 = cx1;
-    *py1 = cy1;
-    *px2 = cx2;
-    *py2 = cy2;
-
-    /* Some safety fudging */
-
-    *px1 -= 2;
-    *py1 -= 2;
-    *px2 += 2;
-    *py2 += 2;
-}
-
 static void
 eel_canvas_re_set_fill (EelCanvasRE *re, gboolean fill_set)
 {
@@ -485,7 +439,6 @@ eel_canvas_re_bounds (EelCanvasItem *item, double *x1, double *y1, double *x2, d
 static void eel_canvas_rect_class_init (EelCanvasRectClass *klass);
 static void eel_canvas_rect_init (EelCanvasRect *rect);
 static void eel_canvas_rect_finalize (GObject *object);
-static void eel_canvas_rect_realize  (EelCanvasItem *item);
 
 static void   eel_canvas_rect_draw   (EelCanvasItem *item, cairo_t *cr, cairo_region_t *region);
 
@@ -497,11 +450,6 @@ struct _EelCanvasRectPrivate
     Rect last_update_rect;
     Rect last_outline_update_rect;
     int last_outline_update_width;
-
-#ifdef HAVE_RENDER
-    gboolean use_render;
-    XRenderPictFormat *format;
-#endif
 };
 
 GType
@@ -545,7 +493,6 @@ eel_canvas_rect_class_init (EelCanvasRectClass *klass)
     item_class->draw = eel_canvas_rect_draw;
     item_class->point = eel_canvas_rect_point;
     item_class->update = eel_canvas_rect_update;
-    item_class->realize = eel_canvas_rect_realize;
 
     G_OBJECT_CLASS (klass)->finalize = eel_canvas_rect_finalize;
 
@@ -570,38 +517,6 @@ eel_canvas_rect_finalize (GObject *object)
     G_OBJECT_CLASS (rect_parent_class)->finalize (object);
 }
 
-static void
-eel_canvas_rect_realize  (EelCanvasItem *item)
-{
-#ifdef HAVE_RENDER
-    EelCanvasRectPrivate *priv;
-    int event_base, error_base;
-    Display *dpy;
-
-    priv = EEL_CANVAS_RECT (item)->priv;
-
-    dpy = GDK_WINDOW_XDISPLAY (gtk_widget_get_window (GTK_WIDGET (item->canvas)));
-    priv->use_render = XRenderQueryExtension (dpy, &event_base, &error_base);
-
-    if (priv->use_render)
-    {
-        GdkVisual *gdk_visual;
-        Visual *visual;
-
-        gdk_visual = gtk_widget_get_visual (GTK_WIDGET (item->canvas));
-        visual = gdk_x11_visual_get_xvisual (gdk_visual);
-
-        priv->format = XRenderFindVisualFormat (dpy, visual);
-    }
-#endif
-
-    if (EEL_CANVAS_ITEM_CLASS (rect_parent_class)->realize)
-    {
-        (* EEL_CANVAS_ITEM_CLASS (rect_parent_class)->realize) (item);
-    }
-}
-
-
 static void
 eel_canvas_set_source_color (cairo_t *cr,
 			     GdkRGBA *rgba)
@@ -682,7 +597,6 @@ eel_canvas_rect_point (EelCanvasItem *item, double x, double y, int cx, int cy,
     double x1, y1, x2, y2;
     double hwidth;
     double dx, dy;
-    double tmp;
 
 #ifdef VERBOSE
     g_print ("eel_canvas_rect_point\n");
@@ -717,6 +631,8 @@ eel_canvas_rect_point (EelCanvasItem *item, double x, double y, int cx, int cy,
 
     if ((x >= x1) && (y >= y1) && (x <= x2) && (y <= y2))
     {
+        double tmp;
+
         if (re->fill_set || !re->outline_set)
             return 0.0;
 
@@ -787,8 +703,6 @@ eel_canvas_rect_update (EelCanvasItem *item, double i2w_dx, double i2w_dy, gint
     double x1, y1, x2, y2;
     int cx1, cy1, cx2, cy2;
     int repaint_rects_count, i;
-    int width_pixels;
-    int width_lt, width_rb;
     Rect update_rect, repaint_rects[4];
     EelCanvasRectPrivate *priv;
 
@@ -819,6 +733,9 @@ eel_canvas_rect_update (EelCanvasItem *item, double i2w_dx, double i2w_dy, gint
 
     if (re->outline_set)
     {
+        int width_pixels;
+        int width_lt, width_rb;
+
         /* Outline and bounding box */
         if (re->width_pixels)
             width_pixels = (int) re->width;
