@@ -246,8 +246,8 @@ eel_str_middle_truncate (const char *string,
     truncated = g_new (char, strlen (string) + 1);
 
     g_utf8_strncpy (truncated, string, num_left_chars);
-    strcat (truncated, delimter);
-    strcat (truncated, g_utf8_offset_to_pointer  (string, length - num_right_chars));
+    g_strlcat (truncated, delimter, (truncate_length + 1));
+    g_strlcat (truncated, g_utf8_offset_to_pointer  (string, length - num_right_chars), (truncate_length + 1));
 
     return truncated;
 }
@@ -293,6 +293,11 @@ eel_str_replace_substring (const char *string,
         return NULL;
     }
 
+    if (replacement == NULL)
+    {
+        replacement = "";
+    }
+
     substring_length = strlen (substring);
     replacement_length = eel_strlen (replacement);
 
@@ -304,7 +309,8 @@ eel_str_replace_substring (const char *string,
         {
             break;
         }
-        result_length += replacement_length - substring_length;
+        if (replacement_length > substring_length)
+            result_length += replacement_length - substring_length;
     }
 
     result = g_malloc (result_length + 1);
@@ -325,7 +331,7 @@ eel_str_replace_substring (const char *string,
         memcpy (result_position, replacement, replacement_length);
         result_position += replacement_length;
     }
-    g_assert (result_position - result == result_length);
+
     result_position[0] = '\0';
 
     return result;
@@ -407,13 +413,14 @@ get_arg_type_from_format (EelPrintfHandler *custom_handlers,
                           const char *format,
                           int len)
 {
-    int i;
     char c;
 
     c = format[len-1];
 
     if (custom_handlers != NULL)
     {
+        int i;
+
         for (i = 0; custom_handlers[i].character != 0; i++)
         {
             if (custom_handlers[i].character == c)
@@ -534,7 +541,6 @@ eel_strdup_vprintf_with_custom (EelPrintfHandler *custom,
     const char *p;
     int num_args, i, j;
     ArgType *args;
-    ArgType type;
     ConversionInfo *conversions;
     GString *f, *str;
     const char *flags, *width, *prec, *mod, *pos;
@@ -671,6 +677,8 @@ eel_strdup_vprintf_with_custom (EelPrintfHandler *custom,
     p = format;
     for (i = 0; i < num_args; i++)
     {
+        ArgType type;
+
         g_string_append_len (str, p, conversions[i].start - p);
         p = conversions[i].end;
 
@@ -678,7 +686,7 @@ eel_strdup_vprintf_with_custom (EelPrintfHandler *custom,
         {
             char *val;
 
-            G_VA_COPY(va, va_orig);
+            va_copy (va, va_orig);
             skip_to_arg (&va, args, custom, conversions[i].precision_pos);
             val = g_strdup_vprintf ("%d", va);
             va_end (va);
@@ -694,7 +702,7 @@ eel_strdup_vprintf_with_custom (EelPrintfHandler *custom,
         {
             char *val;
 
-            G_VA_COPY(va, va_orig);
+            va_copy (va, va_orig);
             skip_to_arg (&va, args, custom, conversions[i].width_pos);
             val = g_strdup_vprintf ("%d", va);
             va_end (va);
@@ -706,7 +714,7 @@ eel_strdup_vprintf_with_custom (EelPrintfHandler *custom,
             g_free (val);
         }
 
-        G_VA_COPY(va, va_orig);
+        va_copy (va, va_orig);
         skip_to_arg (&va, args, custom, conversions[i].arg_pos);
         type = args[conversions[i].arg_pos];
         if (type < 0)
@@ -746,118 +754,6 @@ eel_strdup_printf_with_custom (EelPrintfHandler *handlers,
     return res;
 }
 
-/*********** refcounted strings ****************/
-
-G_LOCK_DEFINE_STATIC (unique_ref_strs);
-static GHashTable *unique_ref_strs = NULL;
-
-static eel_ref_str
-eel_ref_str_new_internal (const char *string, int start_count)
-{
-    char *res;
-    volatile gint *count;
-    gsize len;
-
-    len = strlen (string);
-    res = g_malloc (sizeof (gint) + len + 1);
-    count = (volatile gint *)res;
-    *count = start_count;
-    res += sizeof(gint);
-    memcpy (res, string, len + 1);
-    return res;
-}
-
-eel_ref_str
-eel_ref_str_new (const char *string)
-{
-    if (string == NULL)
-    {
-        return NULL;
-    }
-
-    return eel_ref_str_new_internal (string, 1);
-}
-
-eel_ref_str
-eel_ref_str_get_unique (const char *string)
-{
-    eel_ref_str res;
-
-    if (string == NULL)
-    {
-        return NULL;
-    }
-
-    G_LOCK (unique_ref_strs);
-    if (unique_ref_strs == NULL)
-    {
-        unique_ref_strs =
-            g_hash_table_new(g_str_hash, g_str_equal);
-    }
-
-    res = g_hash_table_lookup (unique_ref_strs, string);
-    if (res != NULL)
-    {
-        eel_ref_str_ref (res);
-    }
-    else
-    {
-        res = eel_ref_str_new_internal (string, 0x80000001);
-        g_hash_table_insert (unique_ref_strs, res, res);
-    }
-
-    G_UNLOCK (unique_ref_strs);
-
-    return res;
-}
-
-eel_ref_str
-eel_ref_str_ref (eel_ref_str str)
-{
-    volatile gint *count;
-
-    count = (volatile gint *)((char *)str - sizeof (gint));
-    g_atomic_int_add (count, 1);
-
-    return str;
-}
-
-void
-eel_ref_str_unref (eel_ref_str str)
-{
-    volatile gint *count;
-    gint old_ref;
-
-    if (str == NULL)
-        return;
-
-    count = (volatile gint *)((char *)str - sizeof (gint));
-
-retry_atomic_decrement:
-    old_ref = g_atomic_int_get (count);
-    if (old_ref == 1)
-    {
-        g_free ((char *)count);
-    }
-    else if (old_ref == 0x80000001)
-    {
-        G_LOCK (unique_ref_strs);
-        /* Need to recheck after taking lock to avoid races with _get_unique() */
-        if (g_atomic_int_add (count, -1) == 0x80000001)
-        {
-            g_hash_table_remove (unique_ref_strs, (char *)str);
-            g_free ((char *)count);
-        }
-        G_UNLOCK (unique_ref_strs);
-    }
-    else if (!g_atomic_int_compare_and_exchange (count,
-             old_ref, old_ref - 1))
-    {
-        goto retry_atomic_decrement;
-    }
-}
-
-
 #if !defined (EEL_OMIT_SELF_CHECK)
 
 static void
@@ -934,8 +830,6 @@ verify_custom (const char *orig, const char *format, ...)
 void
 eel_self_check_string (void)
 {
-    int integer;
-
     EEL_CHECK_INTEGER_RESULT (eel_strlen (NULL), 0);
     EEL_CHECK_INTEGER_RESULT (eel_strlen (""), 0);
     EEL_CHECK_INTEGER_RESULT (eel_strlen ("abc"), 3);
