@@ -22,9 +22,13 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+
+#include <glib/gi18n-lib.h>
+
 #include "caja-column.h"
-#include "caja-extension-i18n.h"
 
 enum {
     PROP_0,
