@@ -24,8 +24,13 @@
 */
 
 #include <config.h>
-#include "caja-desktop-icon-file.h"
+#include <glib/gi18n.h>
+#include <string.h>
+#include <gio/gio.h>
 
+#include <eel/eel-glib-extensions.h>
+
+#include "caja-desktop-icon-file.h"
 #include "caja-desktop-metadata.h"
 #include "caja-desktop-directory-file.h"
 #include "caja-directory-notify.h"
@@ -34,18 +39,14 @@
 #include "caja-file-private.h"
 #include "caja-file-utilities.h"
 #include "caja-file-operations.h"
-#include <eel/eel-glib-extensions.h>
 #include "caja-desktop-directory.h"
-#include <glib/gi18n.h>
-#include <string.h>
-#include <gio/gio.h>
 
-struct CajaDesktopIconFileDetails
+struct _CajaDesktopIconFilePrivate
 {
     CajaDesktopLink *link;
 };
 
-G_DEFINE_TYPE(CajaDesktopIconFile, caja_desktop_icon_file, CAJA_TYPE_FILE)
+G_DEFINE_TYPE_WITH_PRIVATE (CajaDesktopIconFile, caja_desktop_icon_file, CAJA_TYPE_FILE)
 
 
 static void
@@ -166,9 +167,7 @@ desktop_icon_file_get_where_string (CajaFile *file)
 static void
 caja_desktop_icon_file_init (CajaDesktopIconFile *desktop_file)
 {
-    desktop_file->details =	G_TYPE_INSTANCE_GET_PRIVATE (desktop_file,
-                            CAJA_TYPE_DESKTOP_ICON_FILE,
-                            CajaDesktopIconFileDetails);
+    desktop_file->details =	caja_desktop_icon_file_get_instance_private (desktop_file);
 }
 
 static void
@@ -188,8 +187,8 @@ update_info_from_link (CajaDesktopIconFile *icon_file)
         return;
     }
 
-    eel_ref_str_unref (file->details->mime_type);
-    file->details->mime_type = eel_ref_str_get_unique ("application/x-caja-link");
+    g_clear_pointer (&file->details->mime_type, g_ref_string_release);
+    file->details->mime_type = g_ref_string_new_intern ("application/x-caja-link");
     file->details->type = G_FILE_TYPE_SHORTCUT;
     file->details->size = 0;
     file->details->has_permissions = FALSE;
@@ -295,7 +294,7 @@ caja_desktop_icon_file_new (CajaDesktopLink *link)
     icon_file->details->link = link;
 
     name = caja_desktop_link_get_file_name (link);
-    file->details->name = eel_ref_str_new (name);
+    file->details->name = g_ref_string_new (name);
     g_free (name);
 
     update_info_from_link (icon_file);
@@ -330,11 +329,12 @@ caja_desktop_icon_file_unmount (CajaFile                   *file,
                                 gpointer                        callback_data)
 {
     CajaDesktopIconFile *desktop_file;
-    GMount *mount;
 
     desktop_file = CAJA_DESKTOP_ICON_FILE (file);
     if (desktop_file)
     {
+        GMount *mount;
+
         mount = caja_desktop_link_get_mount (desktop_file->details->link);
         if (mount != NULL)
         {
@@ -352,11 +352,12 @@ caja_desktop_icon_file_eject (CajaFile                   *file,
                               gpointer                        callback_data)
 {
     CajaDesktopIconFile *desktop_file;
-    GMount *mount;
 
     desktop_file = CAJA_DESKTOP_ICON_FILE (file);
     if (desktop_file)
     {
+        GMount *mount;
+
         mount = caja_desktop_link_get_mount (desktop_file->details->link);
         if (mount != NULL)
         {
@@ -384,10 +385,8 @@ caja_desktop_icon_file_set_metadata_as_list (CajaFile           *file,
 static void
 caja_desktop_icon_file_class_init (CajaDesktopIconFileClass *klass)
 {
-    GObjectClass *object_class;
     CajaFileClass *file_class;
 
-    object_class = G_OBJECT_CLASS (klass);
     file_class = CAJA_FILE_CLASS (klass);
 
     file_class->default_file_type = G_FILE_TYPE_DIRECTORY;
@@ -405,6 +404,4 @@ caja_desktop_icon_file_class_init (CajaDesktopIconFileClass *klass)
     file_class->set_metadata_as_list = caja_desktop_icon_file_set_metadata_as_list;
     file_class->unmount = caja_desktop_icon_file_unmount;
     file_class->eject = caja_desktop_icon_file_eject;
-
-    g_type_class_add_private (object_class, sizeof(CajaDesktopIconFileDetails));
 }
