@@ -6,6 +6,7 @@
 
    Copyright (C) 2000 Eazel, Inc.
    Copyright (C) 2012 Jasmine Hassan <jasmine.aura@gmail.com>
+   Copyright (C) 2012-2021 The MATE developers
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -26,6 +27,9 @@
             Jasmine Hassan <jasmine.aura@gmail.com>
 */
 
+#ifndef __CAJA_DIRECTORY_BACKGROUND_H__
+#define __CAJA_DIRECTORY_BACKGROUND_H__
+
 #include <eel/eel-background.h>
 
 #include "caja-file.h"
@@ -36,3 +40,6 @@ void     caja_connect_background_to_file_metadata    (GtkWidget         *widget,
                                                       GdkDragAction      default_drag_action);
 
 void     caja_connect_desktop_background_to_settings (CajaIconContainer *icon_container);
+
+#endif	/* __CAJA_DIRECTORY_BACKGROUND_H__ */
+
