@@ -23,8 +23,18 @@
 */
 
 #include <config.h>
-#include "caja-file-utilities.h"
+#include <glib.h>
+#include <glib/gi18n.h>
+#include <glib/gstdio.h>
+#include <gio/gio.h>
+#include <stdlib.h>
 
+#include <eel/eel-glib-extensions.h>
+#include <eel/eel-stock-dialogs.h>
+#include <eel/eel-string.h>
+#include <eel/eel-debug.h>
+
+#include "caja-file-utilities.h"
 #include "caja-global-preferences.h"
 #include "caja-lib-self-check-functions.h"
 #include "caja-metadata.h"
@@ -32,15 +42,6 @@
 #include "caja-file-operations.h"
 #include "caja-search-directory.h"
 #include "caja-signaller.h"
-#include <eel/eel-glib-extensions.h>
-#include <eel/eel-stock-dialogs.h>
-#include <eel/eel-string.h>
-#include <eel/eel-debug.h>
-#include <glib.h>
-#include <glib/gi18n.h>
-#include <glib/gstdio.h>
-#include <gio/gio.h>
-#include <stdlib.h>
 
 #define DEFAULT_CAJA_DIRECTORY_MODE (0755)
 
@@ -54,7 +55,6 @@ static void desktop_dir_changed (void);
 char *
 caja_compute_title_for_location (GFile *location)
 {
-    CajaFile *file;
     char *title;
 
     /* TODO-gio: This doesn't really work all that great if the
@@ -63,6 +63,8 @@ caja_compute_title_for_location (GFile *location)
     title = NULL;
     if (location)
     {
+        CajaFile *file;
+
         file = caja_file_get (location);
         title = caja_file_get_description (file);
         if (title == NULL)
@@ -194,10 +196,8 @@ parse_xdg_dirs (const char *config_file)
     XdgDirEntry dir;
     char *data;
     char **lines;
-    char *p, *d;
-    int i;
-    char *type_start, *type_end;
-    char *value, *unescaped;
+    char *p;
+    char *unescaped;
     gboolean relative;
 
     array = g_array_new (TRUE, TRUE, sizeof (XdgDirEntry));
@@ -211,10 +211,16 @@ parse_xdg_dirs (const char *config_file)
 
     if (g_file_get_contents (config_file, &data, NULL, NULL))
     {
+        int i;
+
         lines = g_strsplit (data, "\n", 0);
         g_free (data);
         for (i = 0; lines[i] != NULL; i++)
         {
+            char *d;
+            char *type_start, *type_end;
+            char *value;
+
             p = lines[i];
             while (g_ascii_isspace (*p))
                 p++;
@@ -280,7 +286,7 @@ parse_xdg_dirs (const char *config_file)
 
     g_free (config_file_free);
 
-    return (XdgDirEntry *)g_array_free (array, FALSE);
+    return (XdgDirEntry *) (gpointer) g_array_free (array, FALSE);
 }
 
 static XdgDirEntry *cached_xdg_dirs = NULL;
@@ -382,10 +388,10 @@ unschedule_user_dirs_changed (void)
 static void
 free_xdg_dir_cache (void)
 {
-    int i;
-
     if (cached_xdg_dirs != NULL)
     {
+        int i;
+
         for (i = 0; cached_xdg_dirs[i].type != NULL; i++)
         {
             if (cached_xdg_dirs[i].file != NULL)
@@ -421,8 +427,7 @@ destroy_xdg_dir_cache (void)
 static void
 update_xdg_dir_cache (void)
 {
-    GFile *file;
-    char *config_file, *uri;
+    char *uri;
     int i;
 
     free_xdg_dir_cache ();
@@ -450,6 +455,9 @@ update_xdg_dir_cache (void)
 
     if (cached_xdg_dirs_monitor == NULL)
     {
+        GFile *file;
+        char *config_file;
+
         config_file = g_build_filename (g_get_user_config_dir (),
                                         "user-dirs.dirs", NULL);
         file = g_file_new_for_path (config_file);
@@ -671,12 +679,13 @@ gboolean
 caja_is_home_directory_file (GFile *dir,
                              const char *filename)
 {
-    char *dirname;
     static GFile *home_dir_dir = NULL;
     static char *home_dir_filename = NULL;
 
     if (home_dir_dir == NULL)
     {
+        char *dirname;
+
         dirname = g_path_get_dirname (g_get_home_dir ());
         home_dir_dir = g_file_new_for_path (dirname);
         g_free (dirname);
@@ -756,6 +765,48 @@ caja_is_desktop_directory (GFile *dir)
     return g_file_equal (dir, desktop_dir);
 }
 
+GMount *
+caja_get_mounted_mount_for_root (GFile *location)
+{
+	GVolumeMonitor *volume_monitor;
+	GList *mounts;
+	GList *l;
+	GMount *mount = NULL;
+	GMount *result = NULL;
+	GFile *root = NULL;
+	GFile *default_location = NULL;
+
+	volume_monitor = g_volume_monitor_get ();
+	mounts = g_volume_monitor_get_mounts (volume_monitor);
+
+	for (l = mounts; l != NULL; l = l->next) {
+		mount = l->data;
+
+		if (g_mount_is_shadowed (mount)) {
+			continue;
+		}
+
+		root = g_mount_get_root (mount);
+		if (g_file_equal (location, root)) {
+			result = g_object_ref (mount);
+			break;
+		}
+
+		default_location = g_mount_get_default_location (mount);
+		if (!g_file_equal (default_location, root) &&
+		    g_file_equal (location, default_location)) {
+			result = g_object_ref (mount);
+			break;
+		}
+	}
+
+	g_clear_object (&root);
+	g_clear_object (&default_location);
+	g_list_free_full (mounts, g_object_unref);
+
+	return result;
+}
+
 /**
  * caja_get_pixmap_directory
  *
@@ -874,8 +925,8 @@ caja_ensure_unique_file_name (const char *directory_uri,
 GFile *
 caja_find_existing_uri_in_hierarchy (GFile *location)
 {
-    GFileInfo *info;
-    GFile *tmp;
+    GFileInfo *info = NULL;
+    GFile *tmp = NULL;
 
     g_assert (location != NULL);
 
@@ -1083,13 +1134,40 @@ caja_is_in_system_dir (GFile *file)
     return res;
 }
 
+gboolean
+caja_is_in_desktop_dir (GFile *file)
+{
+    char *path;
+    char *dirname;
+    gboolean res = FALSE;
+
+    if (!g_file_is_native (file))
+    {
+        return res;
+    }
+
+    path = g_file_get_path (file);
+    dirname = g_path_get_dirname (path);
+    if (g_strcmp0 (dirname, g_get_user_special_dir (G_USER_DIRECTORY_DESKTOP)) == 0)
+    {
+        res = TRUE;
+    }
+
+    g_free (path);
+    g_free (dirname);
+
+    return res;
+}
+
 GHashTable *
 caja_trashed_files_get_original_directories (GList *files,
         GList **unhandled_files)
 {
     GHashTable *directories;
-    CajaFile *file, *original_file, *original_dir;
     GList *l, *m;
+    CajaFile *file = NULL;
+    CajaFile *original_file = NULL;
+    CajaFile *original_dir = NULL;
 
     directories = NULL;
 
@@ -1149,8 +1227,8 @@ caja_trashed_files_get_original_directories (GList *files,
 static GList *
 locations_from_file_list (GList *file_list)
 {
-    CajaFile *file;
     GList *l, *ret;
+    CajaFile *file = NULL;
 
     ret = NULL;
 
@@ -1167,17 +1245,17 @@ void
 caja_restore_files_from_trash (GList *files,
                                GtkWindow *parent_window)
 {
-    CajaFile *file, *original_dir;
     GHashTable *original_dirs_hash;
     GList *original_dirs, *unhandled_files;
-    GFile *original_dir_location;
-    GList *locations, *l;
-    char *message, *file_name;
+    GList *l;
+    CajaFile *file = NULL;
 
     original_dirs_hash = caja_trashed_files_get_original_directories (files, &unhandled_files);
 
     for (l = unhandled_files; l != NULL; l = l->next)
     {
+        char *message, *file_name;
+
         file = CAJA_FILE (l->data);
         file_name = caja_file_get_display_name (file);
         message = g_strdup_printf (_("Could not determine original location of \"%s\" "), file_name);
@@ -1191,6 +1269,10 @@ caja_restore_files_from_trash (GList *files,
 
     if (original_dirs_hash != NULL)
     {
+        CajaFile *original_dir = NULL;
+        GFile *original_dir_location = NULL;
+        GList *locations = NULL;
+
         original_dirs = g_hash_table_get_keys (original_dirs_hash);
         for (l = original_dirs; l != NULL; l = l->next)
         {
@@ -1217,6 +1299,42 @@ caja_restore_files_from_trash (GList *files,
     caja_file_list_unref (unhandled_files);
 }
 
+char *
+caja_get_filesystem_id_by_location (GFile *location, gboolean follow)
+{
+    GFileInfo *info;
+    GFileQueryInfoFlags flags;
+    char *filesystem_id = NULL;
+
+    if (follow) {
+        flags = G_FILE_QUERY_INFO_NONE;
+    } else {
+        flags = G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS;
+    }
+
+    info = g_file_query_info (location, G_FILE_ATTRIBUTE_ID_FILESYSTEM, flags, NULL, NULL);
+    if (info) {
+        if (g_file_info_has_attribute (info, G_FILE_ATTRIBUTE_ID_FILESYSTEM)) {
+            filesystem_id = g_strdup (
+                g_file_info_get_attribute_string (info, G_FILE_ATTRIBUTE_ID_FILESYSTEM));
+        }
+        g_object_unref (info);
+    }
+    return filesystem_id;
+}
+
+char *
+caja_get_filesystem_id_by_uri (const char *uri, gboolean follow)
+{
+    GFile *location;
+    char *filesystem_id;
+
+    location = g_file_new_for_uri (uri);
+    filesystem_id = caja_get_filesystem_id_by_location (location, follow);
+    g_object_unref (location);
+    return filesystem_id;
+}
+
 #if !defined (CAJA_OMIT_SELF_CHECK)
 
 void
