@@ -35,6 +35,7 @@ static char *used_metadata_names[] =
     CAJA_METADATA_KEY_ICON_VIEW_SORT_BY,
     CAJA_METADATA_KEY_ICON_VIEW_SORT_REVERSED,
     CAJA_METADATA_KEY_ICON_VIEW_KEEP_ALIGNED,
+    CAJA_METADATA_KEY_ICON_VIEW_LOCK_ICONS_POSITION,
     CAJA_METADATA_KEY_ICON_VIEW_LAYOUT_TIMESTAMP,
     CAJA_METADATA_KEY_LIST_VIEW_ZOOM_LEVEL,
     CAJA_METADATA_KEY_LIST_VIEW_SORT_COLUMN,
@@ -59,6 +60,7 @@ static char *used_metadata_names[] =
     CAJA_METADATA_KEY_CUSTOM_ICON,
     CAJA_METADATA_KEY_SCREEN,
     CAJA_METADATA_KEY_EMBLEMS,
+    CAJA_METADATA_KEY_TRUSTED_LAUNCHER,
     NULL
 };
 
@@ -66,10 +68,11 @@ guint
 caja_metadata_get_id (const char *metadata)
 {
     static GHashTable *hash;
-    int i;
 
     if (hash == NULL)
     {
+        int i;
+
         hash = g_hash_table_new (g_str_hash, g_str_equal);
         for (i = 0; used_metadata_names[i] != NULL; i++)
             g_hash_table_insert (hash,
