@@ -66,7 +66,16 @@ void           caja_query_set_mime_types     (CajaQuery *query, GList *mime_type
 void           caja_query_add_mime_type      (CajaQuery *query, const char *mime_type);
 
 char *         caja_query_to_readable_string (CajaQuery *query);
-CajaQuery *caja_query_load               (char *file);
+CajaQuery *    caja_query_load               (char *file);
 gboolean       caja_query_save               (CajaQuery *query, char *file);
 
+gint64         caja_query_get_timestamp      (CajaQuery *query);
+void           caja_query_set_timestamp      (CajaQuery *query, gint64 sec);
+
+gint64         caja_query_get_size           (CajaQuery *query);
+void           caja_query_set_size           (CajaQuery *query, gint64 size);
+
+char *         caja_query_get_contained_text (CajaQuery *query);
+void           caja_query_set_contained_text (CajaQuery *query, const char *text);
+
 #endif /* CAJA_QUERY_H */
