@@ -22,11 +22,13 @@
  */
 
 #include <config.h>
-#include "caja-search-engine-tracker.h"
-#include <eel/eel-gtk-macros.h>
 #include <gmodule.h>
 #include <string.h>
 
+#include <eel/eel-gtk-macros.h>
+
+#include "caja-search-engine-tracker.h"
+
 typedef struct _TrackerClient TrackerClient;
 
 typedef enum
@@ -185,10 +187,6 @@ struct CajaSearchEngineTrackerDetails
     TrackerVersion	version;
 };
 
-
-static void  caja_search_engine_tracker_class_init       (CajaSearchEngineTrackerClass *class);
-static void  caja_search_engine_tracker_init             (CajaSearchEngineTracker      *engine);
-
 G_DEFINE_TYPE (CajaSearchEngineTracker,
                caja_search_engine_tracker,
                CAJA_TYPE_SEARCH_ENGINE);
@@ -244,8 +242,6 @@ static void
 search_callback (gpointer results, GError *error, gpointer user_data)
 {
     CajaSearchEngineTracker *tracker;
-    char **results_p;
-    GPtrArray *OUT_result;
     GList *hit_uris;
     gint i;
     char *uri;
@@ -269,6 +265,8 @@ search_callback (gpointer results, GError *error, gpointer user_data)
 
     if (tracker->details->version == TRACKER_0_8)
     {
+        GPtrArray *OUT_result;
+
         /* new tracker 0.8 API */
         OUT_result = (GPtrArray*) results;
 
@@ -287,6 +285,8 @@ search_callback (gpointer results, GError *error, gpointer user_data)
     }
     else
     {
+        char **results_p;
+
         /* old tracker 0.6 API */
         for (results_p = results; *results_p; results_p++)
         {
