@@ -24,28 +24,29 @@
 */
 
 #include <config.h>
-#include "caja-thumbnails.h"
+#include <math.h>
+#include <errno.h>
+#include <stdio.h>
+#include <string.h>
+#include <unistd.h>
+#include <signal.h>
+
+#include <gtk/gtk.h>
+#include <sys/wait.h>
 
 #define MATE_DESKTOP_USE_UNSTABLE_API
+#include <libmate-desktop/mate-desktop-thumbnail.h>
 
-#include "caja-directory-notify.h"
-#include "caja-global-preferences.h"
-#include "caja-file-utilities.h"
-#include <math.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
 #include <eel/eel-graphic-effects.h>
 #include <eel/eel-string.h>
 #include <eel/eel-debug.h>
 #include <eel/eel-vfs-extensions.h>
-#include <gtk/gtk.h>
-#include <errno.h>
-#include <stdio.h>
-#include <string.h>
-#include <sys/wait.h>
-#include <unistd.h>
-#include <signal.h>
-#include <libmate-desktop/mate-desktop-thumbnail.h>
 
+#include "caja-thumbnails.h"
+#include "caja-directory-notify.h"
+#include "caja-global-preferences.h"
+#include "caja-file-utilities.h"
 #include "caja-file-private.h"
 
 /* turn this on to see messages about thumbnail creation */
@@ -189,8 +190,6 @@ thumbnail_thread_starter_cb (gpointer data)
 void
 caja_thumbnail_remove_from_queue (const char *file_uri)
 {
-    GList *node;
-
 #ifdef DEBUG_THUMBNAILS
     g_message ("(Remove from queue) Locking mutex\n");
 #endif
@@ -202,6 +201,8 @@ caja_thumbnail_remove_from_queue (const char *file_uri)
 
     if (thumbnails_to_make_hash)
     {
+        GList *node;
+
         node = g_hash_table_lookup (thumbnails_to_make_hash, file_uri);
 
         if (node && node->data != currently_thumbnailing)
@@ -225,8 +226,6 @@ caja_thumbnail_remove_from_queue (const char *file_uri)
 void
 caja_thumbnail_prioritize (const char *file_uri)
 {
-    GList *node;
-
 #ifdef DEBUG_THUMBNAILS
     g_message ("(Prioritize) Locking mutex\n");
 #endif
@@ -238,6 +237,8 @@ caja_thumbnail_prioritize (const char *file_uri)
 
     if (thumbnails_to_make_hash)
     {
+        GList *node;
+
         node = g_hash_table_lookup (thumbnails_to_make_hash, file_uri);
 
         if (node && node->data != currently_thumbnailing)
@@ -272,10 +273,6 @@ thumbnail_thread_notify_file_changed (gpointer image_uri)
 {
     CajaFile *file;
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-    gdk_threads_enter ();
-#endif
-
     file = caja_file_get_by_uri ((char *) image_uri);
 #ifdef DEBUG_THUMBNAILS
     g_message ("(Thumbnail Thread) Notifying file changed file:%p uri: %s\n", file, (char*) image_uri);
@@ -291,10 +288,6 @@ thumbnail_thread_notify_file_changed (gpointer image_uri)
     }
     g_free (image_uri);
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-    gdk_threads_leave ();
-#endif
-
     return FALSE;
 }
 
@@ -303,8 +296,6 @@ get_types_table (void)
 {
     static GHashTable *image_mime_types = NULL;
     GSList *format_list, *l;
-    char **types;
-    int i;
 
     if (image_mime_types == NULL)
     {
@@ -315,6 +306,9 @@ get_types_table (void)
         format_list = gdk_pixbuf_get_formats ();
         for (l = format_list; l; l = l->next)
         {
+            char **types;
+            int i;
+
             types = gdk_pixbuf_format_get_mime_types (l->data);
 
             for (i = 0; types[i] != NULL; i++)
@@ -394,8 +388,7 @@ caja_create_thumbnail (CajaFile *file)
 {
     time_t file_mtime = 0;
     CajaThumbnailInfo *info;
-    CajaThumbnailInfo *existing_info;
-    GList *existing, *node;
+    GList *existing;
 
     caja_file_set_is_thumbnailing (file, TRUE);
 
@@ -438,6 +431,8 @@ caja_create_thumbnail (CajaFile *file)
     existing = g_hash_table_lookup (thumbnails_to_make_hash, info->image_uri);
     if (existing == NULL)
     {
+        GList *node;
+
         /* Add the thumbnail to the list. */
 #ifdef DEBUG_THUMBNAILS
         g_message ("(Main Thread) Adding thumbnail: %s\n",
@@ -460,6 +455,8 @@ caja_create_thumbnail (CajaFile *file)
     }
     else
     {
+        CajaThumbnailInfo *existing_info;
+
 #ifdef DEBUG_THUMBNAILS
         g_message ("(Main Thread) Updating non-current mtime: %s\n",
                    info->image_uri);
