@@ -26,14 +26,15 @@
  */
 
 #include <config.h>
-#include "caja-bookmark-list.h"
+#include <string.h>
+
+#include <gio/gio.h>
 
 #include <libcaja-private/caja-file-utilities.h>
 #include <libcaja-private/caja-file.h>
 #include <libcaja-private/caja-icon-names.h>
 
-#include <gio/gio.h>
-#include <string.h>
+#include "caja-bookmark-list.h"
 
 #define LOAD_JOB 1
 #define SAVE_JOB 2
@@ -59,9 +60,7 @@ static CajaBookmark *
 new_bookmark_from_uri (const char *uri, const char *label)
 {
     CajaBookmark *new_bookmark;
-    CajaFile *file;
     char *name;
-    GIcon *icon;
     gboolean has_label;
     GFile *location;
     gboolean native;
@@ -87,10 +86,14 @@ new_bookmark_from_uri (const char *uri, const char *label)
 
     if (uri)
     {
+        CajaFile *file;
+        GIcon *icon;
+
         native = g_file_is_native (location);
         file = caja_file_get (location);
 
         icon = NULL;
+
         if (caja_file_check_if_ready (file,
                                       CAJA_FILE_ATTRIBUTES_FOR_ICON))
         {
@@ -212,7 +215,7 @@ do_constructor (GType type,
 
     if (singleton != NULL)
     {
-        return g_object_ref (singleton);
+        return g_object_ref (G_OBJECT (singleton));
     }
 
     retval = G_OBJECT_CLASS (caja_bookmark_list_parent_class)->constructor
@@ -416,7 +419,6 @@ caja_bookmark_list_delete_items_with_uri (CajaBookmarkList *bookmarks,
 {
     GList *node, *next;
     gboolean list_changed;
-    char *bookmark_uri;
 
     g_return_if_fail (CAJA_IS_BOOKMARK_LIST (bookmarks));
     g_return_if_fail (uri != NULL);
@@ -424,6 +426,8 @@ caja_bookmark_list_delete_items_with_uri (CajaBookmarkList *bookmarks,
     list_changed = FALSE;
     for (node = bookmarks->list; node != NULL;  node = next)
     {
+        char *bookmark_uri;
+
         next = node->next;
 
         bookmark_uri = caja_bookmark_get_uri (CAJA_BOOKMARK (node->data));
