@@ -42,6 +42,8 @@
 
 /* Tell screen readers that this is a desktop window */
 
+static GType caja_desktop_window_accessible_get_type (void);
+
 G_DEFINE_TYPE (CajaDesktopWindowAccessible, caja_desktop_window_accessible,
                GTK_TYPE_WINDOW_ACCESSIBLE);
 
@@ -153,12 +155,10 @@ caja_desktop_window_screen_size_changed (GdkScreen             *screen,
         CajaDesktopWindow *window)
 {
     int width_request, height_request;
-    int scale;
 
-    scale = gdk_window_get_scale_factor (gdk_screen_get_root_window (screen));
-
-    width_request = WidthOfScreen (gdk_x11_screen_get_xscreen (screen)) / scale;
-    height_request = HeightOfScreen (gdk_x11_screen_get_xscreen (screen)) / scale;
+    GdkWindow *root_window;
+    root_window = gdk_screen_get_root_window (screen);
+    gdk_window_get_geometry (root_window, NULL, NULL, &width_request, &height_request);
 
     g_object_set (window,
                   "width_request", width_request,
