@@ -45,9 +45,11 @@ caja_file_management_properties_main_close_callback (GtkDialog *dialog,
 int
 main (int argc, char *argv[])
 {
+#ifdef ENABLE_NLS
     bindtextdomain (GETTEXT_PACKAGE, MATELOCALEDIR);
     bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
     textdomain (GETTEXT_PACKAGE);
+#endif /* ENABLE_NLS */
 
     gtk_init (&argc, &argv);
 
