@@ -27,10 +27,12 @@
 
 #include <config.h>
 
-#include <eel/eel-gtk-extensions.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <cairo-gobject.h>
+
+#include <eel/eel-gtk-extensions.h>
+
 #include <libcaja-private/caja-bookmark.h>
 #include <libcaja-private/caja-global-preferences.h>
 #include <libcaja-private/caja-sidebar-provider.h>
@@ -41,13 +43,6 @@
 
 #include "caja-history-sidebar.h"
 
-#define CAJA_HISTORY_SIDEBAR_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST ((klass), CAJA_TYPE_HISTORY_SIDEBAR, CajaHistorySidebarClass))
-#define CAJA_IS_HISTORY_SIDEBAR(obj) \
-  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CAJA_TYPE_HISTORY_SIDEBAR))
-#define CAJA_IS_HISTORY_SIDEBAR_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_TYPE ((klass), CAJA_TYPE_HISTORY_SIDEBAR))
-
 typedef struct
 {
     GtkScrolledWindowClass parent;
@@ -90,11 +85,10 @@ update_history (CajaHistorySidebar *sidebar)
 {
     GtkListStore         *store;
     GtkTreeSelection     *selection;
-    CajaBookmark         *bookmark;
-    cairo_surface_t      *surface;
     GtkTreeIter           iter;
-    char *name;
     GList *l, *history;
+    CajaBookmark         *bookmark = NULL;
+    cairo_surface_t      *surface = NULL;
 
     store = GTK_LIST_STORE (gtk_tree_view_get_model (sidebar->tree_view));
 
@@ -103,6 +97,8 @@ update_history (CajaHistorySidebar *sidebar)
     history = caja_window_info_get_history (sidebar->window);
     for (l = history; l != NULL; l = l->next)
     {
+        char *name;
+
         bookmark = caja_bookmark_copy (l->data);
 
         surface = caja_bookmark_get_surface (bookmark, GTK_ICON_SIZE_MENU);
