@@ -22,15 +22,18 @@
  */
 
 #include <config.h>
-#include "caja-location-dialog.h"
+
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-stock-dialogs.h>
-#include <gtk/gtk.h>
+
 #include <libcaja-private/caja-file-utilities.h>
+
+#include "caja-location-dialog.h"
 #include "caja-location-entry.h"
 #include "caja-desktop-window.h"
-#include <glib/gi18n.h>
 
 struct _CajaLocationDialogDetails
 {
@@ -185,15 +188,21 @@ caja_location_dialog_init (CajaLocationDialog *dialog)
     gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
                         box, FALSE, TRUE, 0);
 
-    gtk_dialog_add_button (GTK_DIALOG (dialog),
-                           GTK_STOCK_HELP,
+    eel_dialog_add_button (GTK_DIALOG (dialog),
+                           _("_Help"),
+                           "help-browser",
                            GTK_RESPONSE_HELP);
-    gtk_dialog_add_button (GTK_DIALOG (dialog),
-                           GTK_STOCK_CANCEL,
+
+    eel_dialog_add_button (GTK_DIALOG (dialog),
+                           _("_Cancel"),
+                           "process-stop",
                            GTK_RESPONSE_CANCEL);
-    gtk_dialog_add_button (GTK_DIALOG (dialog),
-                           GTK_STOCK_OPEN,
+
+    eel_dialog_add_button (GTK_DIALOG (dialog),
+                           _("_Open"),
+                           "document-open",
                            RESPONSE_OPEN);
+
     gtk_dialog_set_default_response (GTK_DIALOG (dialog),
                                      RESPONSE_OPEN);
 
@@ -208,11 +217,9 @@ caja_location_dialog_init (CajaLocationDialog *dialog)
 GtkWidget *
 caja_location_dialog_new (CajaWindow *window)
 {
-    CajaWindowSlot *slot;
     CajaLocationDialog *loc_dialog;
     GtkWidget *dialog;
     GFile *location;
-    char *formatted_location;
 
     dialog = gtk_widget_new (CAJA_TYPE_LOCATION_DIALOG, NULL);
     loc_dialog = CAJA_LOCATION_DIALOG (dialog);
@@ -223,13 +230,15 @@ caja_location_dialog_new (CajaWindow *window)
         gtk_window_set_screen (GTK_WINDOW (dialog),
                                gtk_window_get_screen (GTK_WINDOW (window)));
         loc_dialog->details->window = window;
+        location = window->details->active_pane->active_slot->location;
     }
+    else
+        location = NULL;
 
-    slot = window->details->active_pane->active_slot;
-
-    location = slot->location;
     if (location != NULL)
     {
+        char *formatted_location;
+
         if (CAJA_IS_DESKTOP_WINDOW (window))
         {
             formatted_location = g_strdup_printf ("%s/", g_get_home_dir ());
