@@ -127,8 +127,8 @@ static gboolean caja_path_bar_slider_button_release    (GtkWidget       *widget,
         CajaPathBar *path_bar);
 static void     caja_path_bar_grab_notify              (GtkWidget       *widget,
         gboolean         was_grabbed);
-static void     caja_path_bar_state_changed            (GtkWidget       *widget,
-        GtkStateType     previous_state);
+static void     caja_path_bar_state_flags_changed      (GtkWidget       *widget,
+        GtkStateFlags    previous_state);
 
 static void     caja_path_bar_style_updated            (GtkWidget       *widget);
 
@@ -401,7 +401,7 @@ caja_path_bar_class_init (CajaPathBarClass *path_bar_class)
 
     widget_class->screen_changed = caja_path_bar_screen_changed;
     widget_class->grab_notify = caja_path_bar_grab_notify;
-    widget_class->state_changed = caja_path_bar_state_changed;
+    widget_class->state_flags_changed = caja_path_bar_state_flags_changed;
     widget_class->scroll_event = caja_path_bar_scroll;
 
     container_class->add = caja_path_bar_add;
@@ -1238,8 +1238,8 @@ caja_path_bar_grab_notify (GtkWidget *widget,
 }
 
 static void
-caja_path_bar_state_changed (GtkWidget    *widget,
-                             GtkStateType  previous_state)
+caja_path_bar_state_flags_changed (GtkWidget     *widget,
+                                   GtkStateFlags  previous_state)
 {
     if (!gtk_widget_get_sensitive (widget))
     {
@@ -1610,21 +1610,18 @@ setup_file_path_mounted_mount (GFile *location, ButtonData *button_data)
         {
             result = TRUE;
             /* set mount specific details in button_data */
-            if (button_data)
+            icon = g_mount_get_icon (mount);
+            if (icon == NULL)
             {
-                icon = g_mount_get_icon (mount);
-                if (icon == NULL)
-                {
-                    icon = g_themed_icon_new (CAJA_ICON_FOLDER);
-                }
-                info = caja_icon_info_lookup (icon, CAJA_PATH_BAR_ICON_SIZE, scale);
-                g_object_unref (icon);
-                button_data->custom_icon = caja_icon_info_get_surface_at_size (info, CAJA_PATH_BAR_ICON_SIZE);
-                g_object_unref (info);
-                button_data->dir_name = g_mount_get_name (mount);
-                button_data->type = MOUNT_BUTTON;
-                button_data->fake_root = TRUE;
+                icon = g_themed_icon_new (CAJA_ICON_FOLDER);
             }
+            info = caja_icon_info_lookup (icon, CAJA_PATH_BAR_ICON_SIZE, scale);
+            g_object_unref (icon);
+            button_data->custom_icon = caja_icon_info_get_surface_at_size (info, CAJA_PATH_BAR_ICON_SIZE);
+            g_object_unref (info);
+            button_data->dir_name = g_mount_get_name (mount);
+            button_data->type = MOUNT_BUTTON;
+            button_data->fake_root = TRUE;
             g_object_unref (root);
             break;
         }
@@ -1634,20 +1631,17 @@ setup_file_path_mounted_mount (GFile *location, ButtonData *button_data)
         {
             result = TRUE;
             /* set mount specific details in button_data */
-            if (button_data)
+            icon = g_mount_get_icon (mount);
+            if (icon == NULL)
             {
-                icon = g_mount_get_icon (mount);
-                if (icon == NULL)
-                {
-                    icon = g_themed_icon_new (CAJA_ICON_FOLDER);
-                }
-                info = caja_icon_info_lookup (icon, CAJA_PATH_BAR_ICON_SIZE, scale);
-                g_object_unref (icon);
-                button_data->custom_icon = caja_icon_info_get_surface_at_size (info, CAJA_PATH_BAR_ICON_SIZE);
-                g_object_unref (info);
-                button_data->type = DEFAULT_LOCATION_BUTTON;
-                button_data->fake_root = TRUE;
+                icon = g_themed_icon_new (CAJA_ICON_FOLDER);
             }
+            info = caja_icon_info_lookup (icon, CAJA_PATH_BAR_ICON_SIZE, scale);
+            g_object_unref (icon);
+            button_data->custom_icon = caja_icon_info_get_surface_at_size (info, CAJA_PATH_BAR_ICON_SIZE);
+            g_object_unref (info);
+            button_data->type = DEFAULT_LOCATION_BUTTON;
+            button_data->fake_root = TRUE;
             g_object_unref (default_location);
             g_object_unref (root);
             break;
