@@ -22,23 +22,21 @@
  */
 
 #include <config.h>
-#include "fm-ditem-page.h"
-
 #include <string.h>
 
-#include <eel/eel-glib-extensions.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
+
+#include <eel/eel-glib-extensions.h>
+
 #include <libcaja-extension/caja-extension-types.h>
 #include <libcaja-extension/caja-file-info.h>
 #include <libcaja-private/caja-file.h>
 #include <libcaja-private/caja-file-attributes.h>
 
-#define MAIN_GROUP "Desktop Entry"
+#include "fm-ditem-page.h"
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
-#endif
+#define MAIN_GROUP "Desktop Entry"
 
 typedef struct ItemEntry
 {
@@ -209,8 +207,7 @@ fm_ditem_page_exec_drag_data_received (GtkWidget *widget, GdkDragContext *contex
     char **uris;
     gboolean exactly_one;
     CajaFile *file;
-    GKeyFile *key_file;
-    char *uri, *type, *exec;
+    char *uri, *exec;
 
     uris = g_strsplit (gtk_selection_data_get_data (selection_data), "\r\n", 0);
     exactly_one = uris[0] != NULL && (uris[1] == NULL || uris[1][0] == '\0');
@@ -229,9 +226,14 @@ fm_ditem_page_exec_drag_data_received (GtkWidget *widget, GdkDragContext *contex
     uri = caja_file_get_uri (file);
     if (caja_file_is_mime_type (file, "application/x-desktop"))
     {
+        GKeyFile *key_file;
+
         key_file = _g_key_file_new_from_uri (uri, G_KEY_FILE_NONE, NULL);
+
         if (key_file != NULL)
         {
+            char *type;
+
             type = g_key_file_get_string (key_file, MAIN_GROUP, "Type", NULL);
             if (type != NULL && strcmp (type, "Application") == 0)
             {
@@ -261,7 +263,6 @@ save_entry (GtkEntry *entry, GKeyFile *key_file, const char *uri)
     GError *error;
     ItemEntry *item_entry;
     const char *val;
-    gchar **languages;
 
     item_entry = g_object_get_data (G_OBJECT (entry), "item_entry");
     val = gtk_entry_get_text (entry);
@@ -276,6 +277,8 @@ save_entry (GtkEntry *entry, GKeyFile *key_file, const char *uri)
 
     if (item_entry->localized)
     {
+        gchar **languages;
+
         languages = (gchar **) g_get_language_names ();
         g_key_file_set_locale_string (key_file, MAIN_GROUP, item_entry->field, languages[0], val);
     }
@@ -320,38 +323,21 @@ entry_focus_out_cb (GtkWidget *entry,
 }
 
 static GtkWidget *
-#if GTK_CHECK_VERSION (3, 0, 0)
 build_grid (GtkWidget *container,
-#else
-build_table (GtkWidget *container,
-#endif
              GKeyFile *key_file,
              GtkSizeGroup *label_size_group,
              GList *entries)
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
-	GtkWidget *grid;
-#else
-    GtkWidget *table;
-#endif
-    GtkWidget *label;
-    GtkWidget *entry;
     GList *l;
     char *val;
-#if GTK_CHECK_VERSION (3, 0, 0)
+    GtkWidget *grid;
+    GtkWidget *label;
+    GtkWidget *entry = NULL;
 
-   grid = gtk_grid_new ();
-   gtk_orientable_set_orientation (GTK_ORIENTABLE (grid), GTK_ORIENTATION_VERTICAL);
-   gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
-   gtk_grid_set_column_spacing (GTK_GRID (grid), 12);
-#else
-    int i;
-
-    table = gtk_table_new (g_list_length (entries) + 1, 2, FALSE);
-    gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 12);
-    i = 0;
-#endif
+    grid = gtk_grid_new ();
+    gtk_orientable_set_orientation (GTK_ORIENTABLE (grid), GTK_ORIENTATION_VERTICAL);
+    gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
+    gtk_grid_set_column_spacing (GTK_GRID (grid), 12);
 
     for (l = entries; l; l = l->next)
     {
@@ -362,17 +348,12 @@ build_table (GtkWidget *container,
         label = gtk_label_new (label_text);
         gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
         g_free (label_text);
-#if GTK_CHECK_VERSION (3, 16, 0)
         gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-#else
-        gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
         gtk_size_group_add_widget (label_size_group, label);
 
         entry = gtk_entry_new ();
-#if GTK_CHECK_VERSION (3, 0, 0)
         gtk_widget_set_hexpand (entry, TRUE);
-#endif
+
 
         if (item_entry->localized)
         {
@@ -393,18 +374,9 @@ build_table (GtkWidget *container,
         gtk_entry_set_text (GTK_ENTRY (entry), item_entry->current_value);
         g_free (val);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
         gtk_container_add (GTK_CONTAINER (grid), label);
         gtk_grid_attach_next_to (GTK_GRID (grid), entry, label,
                                   GTK_POS_RIGHT, 1, 1);
-#else
-        gtk_table_attach (GTK_TABLE (table), label,
-                          0, 1, i, i+1, GTK_FILL, GTK_FILL,
-                          0, 0);
-        gtk_table_attach (GTK_TABLE (table), entry,
-                          1, 2, i, i+1, GTK_EXPAND|GTK_FILL, GTK_EXPAND|GTK_FILL,
-                          0, 0);
-#endif
 
         g_signal_connect (entry, "activate",
                           G_CALLBACK (entry_activate_cb),
@@ -438,39 +410,21 @@ build_table (GtkWidget *container,
                               G_CALLBACK (fm_ditem_page_exec_drag_data_received),
                               entry);
         }
-
-#if !GTK_CHECK_VERSION (3, 0, 0)
-        i++;
-#endif
     }
 
     /* append dummy row */
     label = gtk_label_new ("");
-#if GTK_CHECK_VERSION (3, 0, 0)
     gtk_container_add (GTK_CONTAINER (grid), label);
     gtk_size_group_add_widget (label_size_group, label);
 
     gtk_widget_show_all (grid);
     return grid;
-#else
-    gtk_table_attach (GTK_TABLE (table), label,
-                      0, 1, i, i+1, GTK_FILL, GTK_FILL,
-                      0, 0);
-    gtk_size_group_add_widget (label_size_group, label);
-
-    gtk_widget_show_all (table);
-    return table;
-#endif
 }
 
 static void
 create_page (GKeyFile *key_file, GtkWidget *box)
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
     GtkWidget *grid;
-#else
-    GtkWidget *table;
-#endif
     GList *entries;
     GtkSizeGroup *label_size_group;
     char *type;
@@ -507,16 +461,11 @@ create_page (GKeyFile *key_file, GtkWidget *box)
     {
         /* we only handle launchers and links */
 
-        /* ensure that we build an empty table with a dummy row at the end */
-#if GTK_CHECK_VERSION (3, 0, 0)
+        /* ensure that we build an empty gid with a dummy row at the end */
         goto build_grid;
-#else
-        goto build_table;
-#endif
     }
     g_free (type);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 build_grid:
     label_size_group = g_object_get_data (G_OBJECT (box), "label-size-group");
 
@@ -524,15 +473,7 @@ build_grid:
     g_list_free (entries);
 
     gtk_box_pack_start (GTK_BOX (box), grid, FALSE, TRUE, 0);
-#else
-build_table:
-    label_size_group = g_object_get_data (G_OBJECT (box), "label-size-group");
 
-    table = build_table (box, key_file, label_size_group, entries);
-    g_list_free (entries);
-
-    gtk_box_pack_start (GTK_BOX (box), table, FALSE, TRUE, 0);
-#endif
     gtk_widget_show_all (GTK_WIDGET (box));
 }
 
@@ -542,7 +483,6 @@ ditem_read_cb (GObject *source_object,
                GAsyncResult *res,
                gpointer user_data)
 {
-    GKeyFile *key_file;
     GtkWidget *box;
     gsize file_size;
     char *file_contents;
@@ -554,6 +494,8 @@ ditem_read_cb (GObject *source_object,
                                      &file_contents, &file_size,
                                      NULL, NULL))
     {
+        GKeyFile *key_file;
+
         key_file = g_key_file_new ();
         g_object_set_data_full (G_OBJECT (box), "keyfile", key_file, (GDestroyNotify)g_key_file_free);
         if (g_key_file_load_from_data (key_file, file_contents, file_size, 0, NULL))
@@ -588,7 +530,7 @@ fm_ditem_page_make_box (GtkSizeGroup *label_size_group,
 
     g_assert (fm_ditem_page_should_show (files));
 
-    box = gtk_vbox_new (FALSE, 6);
+    box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
     g_object_set_data_full (G_OBJECT (box), "label-size-group",
                             label_size_group, (GDestroyNotify) g_object_unref);
 
