@@ -30,16 +30,15 @@
  */
 
 #include <config.h>
-#include "fm-tree-view.h"
-
-#include "fm-tree-model.h"
-#include "fm-properties-window.h"
 #include <string.h>
-#include <eel/eel-gtk-extensions.h>
+#include <cairo-gobject.h>
+
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
-#include <cairo-gobject.h>
+
+#include <eel/eel-gtk-extensions.h>
+
 #include <libcaja-private/caja-clipboard.h>
 #include <libcaja-private/caja-clipboard-monitor.h>
 #include <libcaja-private/caja-desktop-icon-file.h>
@@ -61,6 +60,10 @@
 #include <libcaja-private/caja-file.h>
 #include <libcaja-private/caja-file-private.h>
 
+#include "fm-tree-view.h"
+#include "fm-tree-model.h"
+#include "fm-properties-window.h"
+
 typedef struct
 {
     GObject parent;
@@ -233,7 +236,7 @@ static gboolean
 show_selection_idle_callback (gpointer callback_data)
 {
     FMTreeView *view;
-    CajaFile *file, *old_file;
+    CajaFile *file;
     GtkTreeIter iter;
     GtkTreePath *path, *sort_path;
 
@@ -249,6 +252,8 @@ show_selection_idle_callback (gpointer callback_data)
 
     if (!caja_file_is_directory (file))
     {
+        CajaFile *old_file;
+
         old_file = file;
         file = caja_file_get_parent (file);
         caja_file_unref (old_file);
